@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright (c) 2011-2020, wradlib developers.
+# Copyright (c) 2011-2021, wradlib developers.
 # Distributed under the MIT License. See LICENSE.txt for more info.
 
 """
@@ -36,24 +36,24 @@ import os.path
 import re
 import warnings
 
-import matplotlib.pyplot as pl
-import mpl_toolkits.axisartist.angle_helper as ah
 import numpy as np
 import xarray as xr
-from matplotlib import axes, lines, patches
-from matplotlib.collections import LineCollection, PolyCollection
-from matplotlib.projections import PolarAxes
-from matplotlib.ticker import FuncFormatter, MaxNLocator, MultipleLocator, NullFormatter
-from matplotlib.transforms import Affine2D
-from mpl_toolkits.axisartist import (
-    GridHelperCurveLinear,
-    ParasiteAxesAuxTrans,
-    SubplotHost,
-)
-from osgeo import osr
 
 from wradlib import georef, io, ipol, util
 
+pl = util.import_optional("matplotlib.pyplot")
+axes = util.import_optional("matplotlib.axes")
+lines = util.import_optional("matplotlib.lines")
+patches = util.import_optional("matplotlib.patches")
+coll = util.import_optional("matplotlib.collections")
+proj = util.import_optional("matplotlib.projections")
+tick = util.import_optional("matplotlib.ticker")
+trans = util.import_optional("matplotlib.transforms")
+axisartist = util.import_optional("mpl_toolkits.axisartist")
+angle_helper = util.import_optional("mpl_toolkits.axisartist.angle_helper")
+osr = util.import_optional("osgeo.osr")
+cartopy = util.import_optional("cartopy")
+
 
 @xr.register_dataarray_accessor("wradlib")
 class WradlibAccessor(object):
@@ -63,7 +63,6 @@ class WradlibAccessor(object):
         self._obj = xarray_obj
         self._site = None
         self._proj = None
-        self.fix_cyclic()
 
     def __getattr__(self, attr):
         return getattr(self._obj, attr)
@@ -71,12 +70,6 @@ class WradlibAccessor(object):
     def __repr__(self):
         return re.sub(r"<.+>", "<{}>".format(self.__class__.__name__), str(self._obj))
 
-    def fix_cyclic(self):
-        rays = self._obj.azimuth
-        dim0 = rays.dims[0]
-        if (360 - (rays[-1] - rays[0])) == (rays[1] - rays[0]):
-            self._obj = xr.concat([self._obj, self._obj.isel({dim0: 0})], dim=dim0)
-
     @property
     def site(self):
         if self._site is None:
@@ -217,8 +210,9 @@ class WradlibAccessor(object):
             if isinstance(proj, collections.abc.Mapping):
                 cg.update(proj)
 
-        if isinstance(proj, osr.SpatialReference):
-            raise TypeError("WRADLIB: Currently GDAL OSR SRS are not supported")
+        if util.has_import(osr):
+            if isinstance(proj, osr.SpatialReference):
+                raise TypeError("WRADLIB: Currently GDAL OSR SRS are not supported")
 
         if isinstance(ax, axes.Axes):
             if cg:
@@ -268,8 +262,7 @@ class WradlibAccessor(object):
                 xp, yp = "gr", "z"
 
         # use cartopy, if available
-        if hasattr(plax, "projection"):
-            cartopy = util.import_optional("cartopy")
+        if hasattr(plax, "projection") and util.has_import(cartopy):
             map_trans = cartopy.crs.AzimuthalEquidistant(
                 central_longitude=self.site[0], central_latitude=self.site[1]
             )
@@ -356,7 +349,7 @@ def plot_ppi(
     rf: float
         If present, factor for scaling range axes, defaults to 1.
     az : :class:`numpy:numpy.ndarray`
-        The azimuth angles in degrees. If None, a default is
+        The azimuth angles in degrees in increasing order. If None, a default is
         calculated from the dimensions of ``data``.
     elev : float or :class:`numpy:numpy.ndarray`
         float or array of same shape as ``az``
@@ -431,7 +424,7 @@ def plot_ppi(
         )
 
     # site must be given, if proj is OSR
-    if isinstance(proj, osr.SpatialReference) and site is None:
+    if util.has_import(osr) and isinstance(proj, osr.SpatialReference) and site is None:
         raise TypeError(
             "WRADLIB: If `proj` is Spatial Reference System "
             "(GDAL OSR SRS) site need to be given "
@@ -480,9 +473,10 @@ def plot_ppi(
 
     da = georef.georeference_dataset(da, proj=proj)
 
-    # fallback to proj=None for GDAL OSR
-    if isinstance(proj, osr.SpatialReference):
-        proj = None
+    if util.has_import(osr):
+        # fallback to proj=None for GDAL OSR
+        if isinstance(proj, osr.SpatialReference):
+            proj = None
 
     pm = da.wradlib.plot_ppi(ax=ax, fig=fig, func=func, proj=proj, **kwargs)
 
@@ -669,7 +663,7 @@ def plot_rhi(
     rf: float
         If present, factor for scaling range axis, defaults to 1.
     th : :class:`numpy:numpy.ndarray`
-        The elevation angles in degrees. If None, a default is
+        The elevation angles in degrees in increasing order. If None, a default is
         calculated from the dimensions of ``data``.
     th_res : float or :class:`numpy:numpy.ndarray`
         float or array of same shape as ``th``.
@@ -800,9 +794,10 @@ def plot_rhi(
 
     da = georef.georeference_dataset(da, proj=proj)
 
-    # fallback to proj=None for GDAL OSR
-    if isinstance(proj, osr.SpatialReference):
-        proj = None
+    if util.has_import(osr):
+        # fallback to proj=None for GDAL OSR
+        if isinstance(proj, osr.SpatialReference):
+            proj = None
 
     pm = da.wradlib.plot_rhi(ax=ax, fig=fig, func=func, proj=proj, **kwargs)
 
@@ -867,16 +862,16 @@ def create_cg(
     """
     # create transformation
     # rotate
-    tr_rotate = Affine2D().translate(rot, 0)
+    tr_rotate = trans.Affine2D().translate(rot, 0)
     # scale
-    tr_scale = Affine2D().scale(scale * np.pi / 180, 1)
+    tr_scale = trans.Affine2D().scale(scale * np.pi / 180, 1)
     # polar
-    tr_polar = PolarAxes.PolarTransform()
+    tr_polar = proj.PolarAxes.PolarTransform()
 
     tr = tr_rotate + tr_scale + tr_polar
 
     # build up curvelinear grid
-    extreme_finder = ah.ExtremeFinderCycle(
+    extreme_finder = angle_helper.ExtremeFinderCycle(
         360,
         360,
         lon_cycle=lon_cycle,
@@ -885,11 +880,11 @@ def create_cg(
         lat_minmax=(latmin, np.inf),
     )
     # locator and formatter for angular annotation
-    grid_locator1 = ah.LocatorDMS(lon_cycle // angular_spacing)
-    tick_formatter1 = ah.FormatterDMS()
+    grid_locator1 = angle_helper.LocatorDMS(lon_cycle // angular_spacing)
+    tick_formatter1 = angle_helper.FormatterDMS()
 
     # grid_helper for curvelinear grid
-    grid_helper = GridHelperCurveLinear(
+    grid_helper = axisartist.GridHelperCurveLinear(
         tr,
         extreme_finder=extreme_finder,
         grid_locator1=grid_locator1,
@@ -912,8 +907,9 @@ def create_cg(
             fig = pl.gcf()
 
     # generate Axis
-    cgax = SubplotHost(fig, subplot, grid_helper=grid_helper)
-    fig.add_axes(cgax)
+    cgax = fig.add_subplot(
+        subplot, axes_class=axisartist.HostAxes, grid_helper=grid_helper
+    )
 
     # get twin axis for cartesian grid
     caax = cgax.twin()
@@ -937,7 +933,7 @@ def create_cg(
     cgax.axis["right"].get_helper().nth_coord_ticks = 0
 
     # generate and add parasite axes with given transform
-    paax = ParasiteAxesAuxTrans(cgax, tr, "equal")
+    paax = cgax.get_aux_axes(tr, "equal")
     # note that paax.transData == tr + cgax.transData
     # Anything you draw in paax will match the ticks and grids of cgax.
     cgax.parasites.append(paax)
@@ -1116,18 +1112,18 @@ def plot_scan_strategy(
     # axes ticks and formatting
     if range_res is not None:
         xloc = range_res
-        caax.xaxis.set_major_locator(MultipleLocator(xloc))
+        caax.xaxis.set_major_locator(tick.MultipleLocator(xloc))
     else:
-        caax.xaxis.set_major_locator(MaxNLocator())
+        caax.xaxis.set_major_locator(tick.MaxNLocator())
     yloc = vert_res
-    caax.yaxis.set_major_locator(MultipleLocator(yloc))
+    caax.yaxis.set_major_locator(tick.MultipleLocator(yloc))
 
     import functools
 
     hform = functools.partial(_height_formatter, cg=cg, scale=scale)
     rform = functools.partial(_range_formatter, scale=scale)
-    caax.yaxis.set_major_formatter(FuncFormatter(hform))
-    caax.xaxis.set_major_formatter(FuncFormatter(rform))
+    caax.yaxis.set_major_formatter(tick.FuncFormatter(hform))
+    caax.xaxis.set_major_formatter(tick.FuncFormatter(rform))
 
     # color management
     from cycler import cycler
@@ -1240,8 +1236,8 @@ def plot_plan_and_vert(
     ax_cb = pl.axes((left + width + height + 0.02, bottom, 0.02, width))
 
     # set axis label formatters
-    ax_x.xaxis.set_major_formatter(NullFormatter())
-    ax_y.yaxis.set_major_formatter(NullFormatter())
+    ax_x.xaxis.set_major_formatter(tick.NullFormatter())
+    ax_y.yaxis.set_major_formatter(tick.NullFormatter())
 
     # draw CAPPI
     pl.sca(ax_xy)
@@ -1270,13 +1266,13 @@ def plot_plan_and_vert(
         """The two args are the value and tick position"""
         return "%d" % (x / 1000.0)
 
-    xyformatter = FuncFormatter(xycoords)
+    xyformatter = tick.FuncFormatter(xycoords)
 
     def zcoords(x, pos):
         """The two args are the value and tick position"""
         return ("%.1f" % (x / 1000.0)).rstrip("0").rstrip(".")
 
-    zformatter = FuncFormatter(zcoords)
+    zformatter = tick.FuncFormatter(zcoords)
 
     ax_xy.xaxis.set_major_formatter(xyformatter)
     ax_xy.yaxis.set_major_formatter(xyformatter)
@@ -1347,9 +1343,9 @@ def add_lines(ax, lines, **kwargs):
     See :ref:`/notebooks/visualisation/wradlib_overlay.ipynb`.
     """
     try:
-        ax.add_collection(LineCollection([lines], **kwargs))
+        ax.add_collection(coll.LineCollection([lines], **kwargs))
     except AssertionError:
-        ax.add_collection(LineCollection([lines[None, ...]], **kwargs))
+        ax.add_collection(coll.LineCollection([lines[None, ...]], **kwargs))
     except ValueError:
         for line in lines:
             add_lines(ax, line, **kwargs)
@@ -1375,9 +1371,9 @@ def add_patches(ax, patch_array, **kwargs):
     """
 
     try:
-        ax.add_collection(PolyCollection([patch_array], **kwargs))
+        ax.add_collection(coll.PolyCollection([patch_array], **kwargs))
     except AssertionError:
-        ax.add_collection(PolyCollection([patch_array[None, ...]], **kwargs))
+        ax.add_collection(coll.PolyCollection([patch_array[None, ...]], **kwargs))
     except ValueError:
         for patch in patch_array:
             add_patches(ax, patch, **kwargs)
